## CSS - Demos - Pagination

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Pagination.mjs"></script>

<webc-container>
    <webc-css-demo-pagination        ></webc-css-demo-pagination> 
    <webc-css-demo-pagination no-css ></webc-css-demo-pagination>
    
</webc-container>